#!/usr/bin/env python

import numpy as np
from astropy.io import fits
import sys
import subprocess

def cleanOIFITS(fitlist):
  """ Removes all nans, infs and values where V^2-sigV^2 > 1"""
  assert fitlist > 1
  
  for rec in fitlist:
      hl = fits.open(rec, mode='update')
      i=0
      while(i < len(hl)):
	  if hl[i].name == 'OI_VIS2':
	      data = hl[i].data
	      v2data = data['VIS2DATA']
	      v2err = data['VIS2ERR']
	      
	      #cleans data with u,v = 0.0
	      zind = np.where((np.absolute(data['UCOORD']) > 1e-6) & 
			     (np.absolute(data['VCOORD']) > 1e-6))[0]	    
	      if len(zind) > 0:
		hl[i].data = data[zind]
		v2data = v2data[zind]
		v2err = v2err[zind]
	      
	      if not np.isnan(v2data).any():
	        ind = np.where(v2data-v2err < 1.0)[0]
	        hl[i].data = hl[i].data[ind]
	      else:
		# cleans data with nans
		del hl[i]
		i=i-1
	  elif hl[i].name == 'OI_T3':
	      print "Deleting T3."
	      del hl[i]
	      i=i-1
	  i+=1    
		
      hl.info()	      
      hl.flush();
      hl.close();
      
def main():
    if len(sys.argv) == 1:
	print "Call: script.py -f listFile"
	sys.exit(1)
  
    while len(sys.argv) > 1:
	opt = sys.argv[1];		del sys.argv[1];
	if opt == '-f':
	    inFile = sys.argv[1];	del sys.argv[1];
	      
    try:
	ifile = open(inFile, 'r')
	fitList = ifile.readlines()
	ifile.close()
	fitList = [x.rstrip('\n') for x in fitList]
    except:
	print "Could not read %s" % (inFile)
    
    cleanOIFITS(fitList)    
    
if __name__=='__main__':
    main()
    
    
  
    
