#!/usr/bin/env python

from pyshellspec.include import oifits
import argparse
import numpy as np


npband = 7

def set_error(t3, t3err, cperr, deltacp):
    """
    Adjusts MIRC error according to Monnier et al. 2012, 761:L3
    @return:
    """
    # computes signal to noise ratio for t3amp 
    snr = t3 / t3err
    
    if snr <= 2.:
        cperr = max([1.0, 30. / snr ** 2, 0.2 * deltacp, cperr])
    else:
        cperr = max([1.0, cperr])
        
    return cperr

def main():
    """
    The main body.
    @return:
    """
    # parse command line argument
    ps = argparse.ArgumentParser()
    ps.add_argument('-f', type=str, required=True, help='Name of the adjusted file.')
    args = ps.parse_args()
    
    # open the fits file
    hdu = oifits.oifits.open(args.f)

    # get closure phase
    t3 = hdu.t3
    
    # get effective wavelengths
    data = dict(eff_wave=[], deltacp=[])
    
    # go over the observations
    for i in range(npband):
        
        #append the effective wavelength
        data['eff_wave'].append(t3[0].wavelength.eff_wave[i])

        # go over the obsrvations to determine mean cp
        cp = []
        for obs in t3:
            cp.append(obs.t3phi[i])
            
        # append the spread
        data['deltacp'].append(np.max(cp) - np.min(cp))
        
    for i in range(npband):
        for obs in t3:
            # take out the observables
            amp = obs.t3amp[i]
            amperr = obs.t3amperr[i]
            cperr = obs.t3phierr[i]
            
            # set new error in low SNR data
            cperrnew = set_error(amp, amperr, cperr, data['deltacp'][i])
            
            # assign
            obs.t3phierr[i] = cperrnew
            
            # print amp / amperr, obs.t3phierr[i], cperr, cperrnew
    hdu.save(args.f)
        
if __name__ == '__main__':
    main() 
